\name{mix.fish}
\alias{mix.fish}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Wrapper for R2WinBUGS and Bugs }
\description{
  Formats and passes a host of variables for otolith element and genetic data for processing in WinBUGS via R2WinBUGS.
}
\usage{

mix.fish(data, method=c("combined","otolith","genetic")[1], groups, loci=NULL, otolith.var=NULL, 
mixparameters=NULL, base, basetows=NULL, mix, mixtows=NULL, gmethod = c("pbayes","rmprior")[1], 
type= c("random", "fixed")[1], max.prob = 0.9, n.chains = 2, n.iter=200, n.burnin=floor(n.iter/2), 
n.thin=max(1, floor(n.chains * (n.iter - n.burnin) / n.sims)), 
n.sims = 1000, debug=FALSE, tol = 0.0001)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{ an object of class data.frame containing records of otolith elemental composition or genetic allele frequencies or
  both kinds of data as well as columns identifying records as coming from base samples or mix samples}
  \item{method}{indicates form of mixture analysis requested. Default is combined (genetic and otolith data). }
  \item{groups}{ a character variable identifying all base and mix groups such as stocks, catch locations, or rearing tanks }
  \item{loci}{a character vector indentifying column labels for each locus. Two columns are expected for each loci "xx", labelled "xx\_1" "xx\_2" corresponding to
  the alleles on each chromosome in \code{data}.}
  \item{otolith.var}{a character vector of the column names of the otolith elements to be analyzed.}
  \item{mixparameters}{a character vector of the names of the stochastic nodes to be monitored by WinBUGS and returned to R.  For the
\eqn{i}th mix sample \eqn{(i=1,\ldots,I)}, \eqn{P\_i} is a vector of
the proportion for the mix sample records assigned to base groups
\eqn{j=1,\ldots,J}. See example below for monitoring  \eqn{I=4} mix
samples. \code{mixparameters}=NULL results in all stochastic nodes
being monitored and returned to R.}
  \item{base}{ a vector indicating base records in \code{data}.}
  \item{basetows}{ an (optional) vector containing a subgroup of \code{base}.}
  \item{mix}{ a vector indicating mixed records in \code{data}.}
  \item{mixtows}{ an (optional) vector containing a subgroup of \code{mix}.}
  \item{gmethod}{ a method for setting priors for the allele frequencies for each loci in the genetic data.
   \code{pbayes} = pseudo Bayes method suggested by Pella and Masuda (2001); \code{rmprior}= equiprobable prior for allele relative frequencies
   suggested by Rannala and Mountain (1997).}
  \item{type}{a setting for initial values for base group membership for each of the mix samples. 
  \dQuote{fixed} = initial values sampled from a multinomial distribution of base group membership with unequal probabilities for the base groups. 
   For this option each mix sample is assigned group \eqn{j} membership with probability \eqn{p_j} (see \code{max.prob}) with \eqn{j} chosen randomly for each 
   mix sample.  
  or \dQuote{random}= initial values sampled from a multinomial distribution of base group membership with equal probabilities over all of the \eqn{J} for base groups.}
  \item{max.prob}{a positive number between 0 and 1 indicating maximum probability \eqn{p_j} for \code{type}=fixed. Setting max.prob close to 
  1.0 may result in poor convergence. Default = 0.90.}
  \item{n.chains}{ number of n.chains in \code{\link{bugs}}. Default = 2 }
  \item{n.iter}{ number of n.iter in \code{\link{bugs}}. Default = 200 }
   \item{n.burnin}{length of burn in, i.e. number of iterations to discard at the beginning. Default is \eqn{n.iter/2}, that is, discarding the first half of the simulations.}
  \item{n.thin}{thinning rate. Must be a positive integer. Set \eqn{n.thin} > 1 to save memory and computation time if \eqn{n.iter} is large. Default is \eqn{max(1, floor(n.chains * (n.iter-n.burnin) / 1000))} which will only thin if there are at least 2000 simulations.}  
  \item{n.sims}{The approximate number of simulations to keep after thinning.}

  \item{debug}{debug status in \code{\link{bugs}}. Default = FALSE }
  \item{tol}{A positive numeric value specifying the tolerance level for convergence criterion for 
  \code{gmethod} = \code{pbayes}. Default=0.0001}
  }

 \details{
Performs a Bayesian analysis using WinBUGS through R2WinBUGS on either or both of genetic or otolith data. This function is a wrapper for all functions provided in this package.
}

\value{
%  ~Describe the value returned
%  If it is a LIST, use
%  \item{comp1 }{Description of 'comp1'}
%  \item{comp2 }{Description of 'comp2'}
%  ...
\code{mixture.bayes} returns an object of \code{\link{class}} "bugs".

}


\references{

Pella, J. and Masuda, M. (2001) Bayesian methods for analysis of
stock mixtures from genetic characters. \emph{Fisheries Bulletin} \bold{99}: 151--167.

Rannala, B. and Mountain, J.L. (1997) Detecting immigration by
using multilocus genotypes. \emph{Proceedings of the National Academies of Science, U.S.A.} \bold{94}:
9197--9201.

Smith, S.J. and S. E. Campana.  (2010) Integrated
stock mixture analysis for continuous and categorical data, with
application to genetic-otolith combinations. \emph{Canadian Journal of
Fisheries and Aquatic Science.} \bold{67}: 1533--1548.

}

\author{Original code written by Trevor Avery \email{trevor.avery@acadiau.ca}.
Modified by S.J. Smith, DFO, Dartmouth, NS, Canada. \email{Stephen.Smith@dfo-mpo.gc.ca}}

\note{ 
WinBugs version 1.43 must be installed for this package to work.  See  \url{http://www.mrc-bsu.cam.ac.uk/bugs/} for details.

}

\seealso{
\code{\link{print.bugs}}, \code{\link{plot.bugs}}.
}

\examples{
data(codmix)
 
mymix<-mix.fish(data=codmix,method="otolith",groups="STOCK",
otolith.var=c("BA", "LILN", "MGLNDET2", "MNDET2", "SRDET2"), 
mixparameters=c("P1","P2","P3","P4"),base=codmix[codmix$SEASON=="S96",],
basetows=c("3Pn4RS","3Ps","4T","4Vs"),mix=codmix[codmix$SEASON=="J96",],
mixtows=c("3Pn4RS","3Ps","4Vn","4Vs"),type="random",n.chains=2,n.iter=2000)

 }

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ models }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
